ballclust: Fast VII Gaussian Mixture Model

View source: R/ClusterVII.R

ballclustR Documentation

Fast VII Gaussian Mixture Model

Description

Fast VII Gaussian Mixture Model

Usage

ballclust(
  data,
  G = NULL,
  threads = parallel::detectCores() - 1,
  min_pts = 5,
  verbose = FALSE
)

Arguments

data

A numeric matrix or data frame.

G

An integer vector specifying the numbers of mixture components. If NULL, defaults to 1:9.

threads

Number of threads for OpenMP parallelization.

min_pts

an integer to specify the minimum number of points inside a cluster. Default: 5

verbose

logical. if TRUE, print out additional messages. Default: FALSE

Value

An object of class ballclust, mimicking mclust.


GridOnClusters documentation built on July 18, 2026, 5:07 p.m.