cluster: Cluster Multivariate Data

View source: R/discretize_jointly.R

clusterR Documentation

Cluster Multivariate Data

Description

The function obtains clusters from data using the given number of clusters, which may be a range.

Usage

cluster(data, k, method, noise, min_pts, nthread)

Arguments

data

input continuous multivariate data

k

the number(s) of clusters

method

the method for clustering

noise

adding jitter noise to the data or not

min_pts

an integer to specify the minimum number of points inside a cluster.

nthread

an integer to specify the number of threads


GridOnClusters documentation built on July 18, 2026, 5:07 p.m.