plot.GridOnClusters: Plotting the continuous data along with cluster-preserving...

View source: R/plot_patterns.R

plot.GridOnClustersR Documentation

Plotting the continuous data along with cluster-preserving Grid

Description

Plots examples of jointly discretizing continuous data based on grids that preserve clusters in the original data.

Usage

## S3 method for class 'GridOnClusters'
plot(
  x,
  xlab = NULL,
  ylab = NULL,
  main = NULL,
  main.table = NULL,
  col,
  line_col = "black",
  cex = 1.125,
  sub = NULL,
  pch = 19,
  plot.table = TRUE,
  ...
)

Arguments

x

the result generated by discretize.jointly

xlab

the horizontal axis label

ylab

the vertical axis label

main

the title of the clustering scatter plots

main.table

the title of the discretized data plots

col

the color of data points

line_col

the color of grid lines

cex

A numerical value giving the amount by which plotting text and symbols should be magnified relative to the default.

sub

the subtitle

pch

the symbol for points on the scatter plots

plot.table

a logical to show the contingency table. Default: TRUE.

...

additional graphical parameters


GridOnClusters documentation built on July 18, 2026, 5:07 p.m.