| ballclust | R Documentation |
Fast VII Gaussian Mixture Model
ballclust(
data,
G = NULL,
threads = parallel::detectCores() - 1,
min_pts = 5,
verbose = FALSE
)
data |
A numeric matrix or data frame. |
G |
An integer vector specifying the numbers of mixture components. If NULL, defaults to 1:9. |
threads |
Number of threads for OpenMP parallelization. |
min_pts |
an integer to specify the minimum number of points inside a cluster. Default: 5 |
verbose |
logical. if |
An object of class ballclust, mimicking mclust.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.