View source: R/discretize_jointly.R
| cluster | R Documentation |
The function obtains clusters from data using the given number of clusters, which may be a range.
cluster(data, k, method, noise, min_pts, nthread)
data |
input continuous multivariate data |
k |
the number(s) of clusters |
method |
the method for clustering |
noise |
adding jitter noise to the data or not |
min_pts |
an integer to specify the minimum number of points inside a cluster. |
nthread |
an integer to specify the number of threads |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.